# PoisonApple

<img src="poisonapple.png" align="right">

Command-line tool to perform various persistence mechanism techniques on macOS.

## Install

Do it up:
```
$ pip install poisonapple --user
```